Module: Cucumber::Formatter::ANSIColor
Overview
Defines aliases for coloured output. You can tweak the colours by defining a CUCUMBER_COLORS variable in your shell, very much like you can tweak the familiar POSIX command ls with $LSCOLORS/$LS_COLORS
The colours that you can change are:
- undefined - defaults to yellow
- pending - defaults to yellow
- pending_param - defaults to yellow,bold
- failed - defaults to red
- failed_param - defaults to red,bold
- passed - defaults to green
- passed_param - defaults to green,bold
- outline - defaults to cyan
- outline_param - defaults to cyan,bold
- skipped - defaults to cyan
- skipped_param - defaults to cyan,bold
- comment - defaults to grey
- tag - defaults to cyan
For instance, if your shell has a black background and a green font (like the "Homebrew" settings for OS X' Terminal.app), you may want to override passed steps to be white instead of green. Examples:
export CUCUMBER_COLORS="passed=white"
export CUCUMBER_COLORS="passed=white,bold:passed_param=white,bold,underline"
(If you're on Windows, use SET instead of export). To see what colours and effects are available, just run this in your shell:
ruby -e "require 'rubygems'; require 'term/ansicolor'; puts Term::ANSIColor.attributes"
Although not listed, you can also use grey
Constant Summary collapse
- ALIASES =
Hash.new do |h,k| if k.to_s =~ /(.*)_param/ h[$1] + ',bold' end end.merge({ 'undefined' => 'yellow', 'pending' => 'yellow', 'failed' => 'red', 'passed' => 'green', 'outline' => 'cyan', 'skipped' => 'cyan', 'comment' => 'grey', 'tag' => 'cyan' })
Instance Method Summary collapse
-
#grey(m) ⇒ Object
Not supported in Term::ANSIColor.
Instance Method Details
#grey(m) ⇒ Object
Not supported in Term::ANSIColor
64 65 66 67 68 69 70 |
# File 'lib/cucumber/formatter/ansicolor.rb', line 64 def grey(m) if ::Term::ANSIColor.coloring? "\e[90m#{m}\e[0m" else m end end |